<?php

    /** @noinspection PhpMissingFieldTypeInspection */

    namespace RssLib\Objects\RssChannel;

    use InvalidArgumentException;
    use RssLib\Interfaces\SerializableObjectInterface;

    class TextInput implements SerializableObjectInterface
    {
        /**
         * @var string
         */
        private $title;

        /**
         * @var string
         */
        private $description;

        /**
         * @var string
         */
        private $name;

        /**
         * @var string
         */
        private $link;

        /**
         * Public Constructor
         *
         * @param array $data
         */
        public function __construct(array $data)
        {
            foreach(['title', 'description', 'name', 'link'] as $key)
            {
                if(!array_key_exists($key, $data))
                {
                    throw new InvalidArgumentException(sprintf('Missing required key %s for text input', $key));
                }
            }

            $this->title = (string)$data['title'];
            $this->description = (string)$data['description'];
            $this->name = (string)$data['name'];
            $this->link = (string)$data['link'];
        }

        /**
         * The label of the Submit button in the text input area.
         *
         * @return string
         */
        public function getTitle(): string
        {
            return $this->title;
        }

        /**
         * Explains the text input area.
         *
         * @return string
         */
        public function getDescription(): string
        {
            return $this->description;
        }

        /**
         * The name of the text object in the text input area.
         *
         * @return string
         */
        public function getName(): string
        {
            return $this->name;
        }

        /**
         * The URL of the CGI script that processes text input requests.
         *
         * @return string
         */
        public function getLink(): string
        {
            return $this->link;
        }

        /**
         * @inheritDoc
         */
        public function toArray(): array
        {
            return [
                'title' => $this->title,
                'description' => $this->description,
                'name' => $this->name,
                'link' => $this->link
            ];
        }

        /**
         * @inheritDoc
         */
        public static function fromArray(array $array): TextInput
        {
            return new self($array);
        }
    }