<?php

    /** @noinspection PhpMissingFieldTypeInspection */

    namespace RssLib\Objects\RssFeed;

    use InvalidArgumentException;
    use RssLib\Interfaces\SerializableObjectInterface;

    class Enclosure implements SerializableObjectInterface
    {
        /**
         * @var string
         */
        private $url;

        /**
         * @var int
         */
        private $length;

        /**
         * @var string
         */
        private $type;

        /**
         * Public Constructor
         *
         * @param array $data
         */
        public function __construct(array $data)
        {
            foreach(['enclosure_url', 'enclosure_length', 'enclosure_type'] as $key)
            {
                if(!array_key_exists($key, $data))
                {
                    throw new InvalidArgumentException(sprintf('Missing required key %s for enclosure', $key));
                }
            }

            $this->url = (string)$data['enclosure_url'];
            $this->length = (int)$data['enclosure_length'];
            $this->type = (string)$data['enclosure_type'];
        }

        /**
         * Required. Defines the URL to the media file
         *
         * @return string
         */
        public function getUrl(): string
        {
            return $this->url;
        }

        /**
         * Required. Defines the length of the media file in bytes
         *
         * @return string
         */
        public function getLength(): string
        {
            return $this->length;
        }

        /**
         * Required. Defines the MIME type of the media file
         *
         * @return string
         */
        public function getType(): string
        {
            return $this->type;
        }

        /**
         * @inheritDoc
         */
        public function toArray(): array
        {
            return [
                'enclosure_url' => $this->url,
                'enclosure_length' => $this->length,
                'enclosure_type' => $this->type
            ];
        }

        /**
         * @inheritDoc
         */
        public static function fromArray(array $array): Enclosure
        {
            return new self($array);
        }
    }