<?php

    /** @noinspection PhpMissingFieldTypeInspection */

    namespace RssLib\Objects\RssFeed;

    use InvalidArgumentException;
    use RssLib\Interfaces\SerializableObjectInterface;

    class Guid implements SerializableObjectInterface
    {
        /**
         * @var string
         */
        private $guid;

        /**
         * @var bool
         */
        private $is_permalink;

        /**
         * Public Constructor
         *
         * @param array $data
         */
        public function __construct(array $data)
        {
            if(!array_key_exists('guid', $data))
            {
                throw new InvalidArgumentException('Missing required key guid for guid');
            }

            $this->guid = (string)$data['guid'];

            if(array_key_exists('guid_isPermalink', $data))
            {
                $this->is_permalink = (bool)$data['guid_isPermalink'];
            }
            else
            {
                $this->is_permalink = false;
            }
        }

        /**
         * Returns the guid
         *
         * @return string
         */
        public function getGuid(): string
        {
            return $this->guid;
        }

        /**
         * Returns True if the guid is a permalink, False otherwise
         *
         * @return bool
         */
        public function isPermalink(): bool
        {
            return $this->is_permalink;
        }

        /**
         * @inheritDoc
         */
        public function toArray(): array
        {
            return [
                'guid' => $this->guid,
                'guid_isPermalink' => $this->is_permalink
            ];
        }

        /**
         * @inheritDoc
         */
        public static function fromArray(array $array): Guid
        {
            return new Guid($array);
        }
    }