<?php

    /** @noinspection PhpMissingFieldTypeInspection */

    namespace RssLib\Objects\RssFeed;

    use InvalidArgumentException;
    use RssLib\Interfaces\SerializableObjectInterface;

    class Source implements SerializableObjectInterface
    {
        /**
         * @var string
         */
        private $url;

        /**
         * @var string
         */
        private $source;

        /**
         * Public Constructor
         *
         * @param array $data
         */
        public function __construct(array $data)
        {
            foreach(['source', 'source_url'] as $key)
            {
                if(!array_key_exists($key, $data))
                {
                    throw new InvalidArgumentException(sprintf('Missing required key %s for source', $key));
                }
            }

            $this->url = (string)$data['source_url'];
            $this->source = (string)$data['source'];
        }

        /**
         * Returns the url
         *
         * @return string
         */
        public function getUrl(): string
        {
            return $this->url;
        }

        /**
         * Returns the source
         *
         * @return string
         */
        public function getSource(): string
        {
            return $this->source;
        }

        /**
         * @inheritDoc
         */
        public function toArray(): array
        {
            return [
                'source_url' => $this->url,
                'source' => $this->source
            ];
        }

        /**
         * @inheritDoc
         */
        public static function fromArray(array $array): Source
        {
            return new static($array);
        }
    }