<?php

    namespace RssLib;

    use Exception;
    use RssLib\Classes\Utilities;
    use RssLib\Exceptions\RssFeedException;
    use RssLib\Objects\RssChannel;

    class RssLib
    {
        /**
         * @param string $url
         * @param int $timeout
         * @return RssChannel
         * @throws RssFeedException
         */
        public static function getFeed(string $url, int $timeout=120): RssChannel
        {
            return self::parseRssContent(self::fetchRssContent($url, $timeout));
        }

        /**
         * Fetches the RSS feed from the given URL and returns the content.
         *
         * @param string $url
         * @param int $timeout
         * @return string
         * @throws RssFeedException
         */
        public static function fetchRssContent(string $url, int $timeout=120): string
        {
            try
            {
                $ch = curl_init($url);
                curl_setopt($ch, CURLOPT_URL, $url);
                curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);
                curl_setopt($ch, CURLOPT_HEADER, false);
                curl_setopt($ch, CURLOPT_FOLLOWLOCATION, true);
                curl_setopt($ch, CURLOPT_TIMEOUT, $timeout);

                $content = curl_exec($ch);

                if(curl_errno($ch))
                {
                    throw new RssFeedException(sprintf('Failed to fetch RSS feed from %s: %s', $url, curl_error($ch)));
                }
            }
            catch(Exception $e)
            {
                throw new RssFeedException(sprintf('Failed to fetch RSS feed from %s', $url), 0, $e);
            }
            finally
            {
                curl_close($ch);
                unset($ch);
            }

            return $content;
        }

        /**
         * @param string $content
         * @return RssChannel
         */
        public static function parseRssContent(string $content): RssChannel
        {
            return new RssChannel(Utilities::xmlToArray(simplexml_load_string($content))['channel']);
        }
    }